from setuptools import setup
import os

setup(
    name='cm-course-uos',
    version='1.0',
    description='A brief description of your package',
    long_description='A longer description of your package',
    author='Your Name',
    author_email='your@email.com',
    url='https://github.com/yourusername/your-repo',
    install_requires=[
        # List any dependencies your package requires
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
    ],
)